@@ -202,6 +202,7 @@ def main():
                 print
                 dataToStdout(excMsg)
                 raise SystemExit
+
             elif any(_ in excMsg for _ in ("No space left", "Disk quota exceeded")):
                 errMsg = "no space left on output device"
                 logger.error(errMsg)
@@ -219,6 +220,11 @@ def main():
                 logger.error(errMsg)
                 raise SystemExit
 
+            elif "OperationalError: disk I/O error" in excMsg:
+                errMsg = "I/O error on output device"
+                logger.error(errMsg)
+                raise SystemExit
+
             elif "_mkstemp_inner" in excMsg:
                 errMsg = "there has been a problem while accessing temporary files"
                 logger.error(errMsg)
@@ -300,7 +306,7 @@ def main():
 
         if hasattr(conf, "api"):
             try:
-                conf.database_cursor.disconnect()
+                conf.databaseCursor.disconnect()
             except KeyboardInterrupt:
                 pass
 
@@ -314,10 +320,10 @@ def main():
                 time.sleep(0.01)
         except KeyboardInterrupt:
             pass
-
-        # Reference: http://stackoverflow.com/questions/1635080/terminate-a-multi-thread-python-program
-        if threading.activeCount() > 1:
-            os._exit(0)
+        finally:
+            # Reference: http://stackoverflow.com/questions/1635080/terminate-a-multi-thread-python-program
+            if threading.activeCount() > 1:
+                os._exit(0)
 
 if __name__ == "__main__":
     main()
